==> haskell-hasql-transaction-0.7.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.7.1
id: hasql-transaction-0.7.1-4dfE5EToVUrHXJfWjfGUkc
key: hasql-transaction-0.7.1-4dfE5EToVUrHXJfWjfGUkc
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
abi: 35a3135f1a951504d7b1a556e709de84
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Statements
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
import-dirs: /usr/lib/ghc-8.6.4/site-local/hasql-transaction-0.7.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/hasql-transaction-0.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hasql-transaction-0.7.1
hs-libraries: HShasql-transaction-0.7.1-4dfE5EToVUrHXJfWjfGUkc
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    bytestring-tree-builder-0.2.7.2-4YeH8uf92Tx2jD1lPXubVG
    contravariant-1.5-6YjeCNapF4KLECQA4h7stV
    contravariant-extras-0.3.4-LS2OolzRbnV1PjJqBFISq0
    hasql-1.3.0.3-GNZeuAYqrlcI4KsdyeAlAJ mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-transaction-0.7.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-transaction.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-transaction
version: 0.7.1
id: hasql-transaction-0.7.1-6qPfWPatb36HvadYcScr0O
key: hasql-transaction-0.7.1-6qPfWPatb36HvadYcScr0O
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-transaction
synopsis: A composable abstraction over the retryable transactions for Hasql
category: Hasql, Database, PostgreSQL
abi: 745deea4113b24c6efc10377a8e5ec7d
exposed: True
exposed-modules:
    Hasql.Transaction Hasql.Transaction.Sessions
hidden-modules: Hasql.Transaction.Private.Prelude
                Hasql.Transaction.Private.Model Hasql.Transaction.Private.SQL
                Hasql.Transaction.Private.Statements
                Hasql.Transaction.Private.Sessions
                Hasql.Transaction.Private.Transaction
import-dirs: /usr/lib/ghc-8.6.4/site-local/hasql-transaction-0.7.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/hasql-transaction-0.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hasql-transaction-0.7.1
hs-libraries: HShasql-transaction-0.7.1-6qPfWPatb36HvadYcScr0O
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    bytestring-tree-builder-0.2.7.2-MedxFZwpjO3JSNIqGYjgz
    contravariant-1.5-6YjeCNapF4KLECQA4h7stV
    contravariant-extras-0.3.4-LS2OolzRbnV1PjJqBFISq0
    hasql-1.3.0.3-LYsU9JRoLRPDYatjIa1AKU mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hasql-transaction/html/hasql-transaction.haddock
haddock-html: /usr/share/doc/haskell-hasql-transaction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
